import moment from "moment";

const Article = ({ author, text, date, image }) => {

    moment.locale('fr', {
        months : 'janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre'.split('_'),
        monthsShort : 'janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.'.split('_'),
        monthsParseExact : true,
        weekdays : 'dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi'.split('_'),
        weekdaysShort : 'dim._lun._mar._mer._jeu._ven._sam.'.split('_'),
        weekdaysMin : 'Di_Lu_Ma_Me_Je_Ve_Sa'.split('_'),
        weekdaysParseExact : true,
        longDateFormat : {
            LT : 'HH:mm',
            LTS : 'HH:mm:ss',
            L : 'DD/MM/YYYY',
            LL : 'D MMMM YYYY',
            LLL : 'D MMMM YYYY HH:mm',
            LLLL : 'dddd D MMMM YYYY HH:mm'
        },
        calendar : {
            sameDay : '[Aujourd’hui à] LT',
            nextDay : '[Demain à] LT',
            nextWeek : 'dddd [à] LT',
            lastDay : '[Hier à] LT',
            lastWeek : 'dddd [dernier à] LT',
            sameElse : 'L'
        },
        relativeTime : {
            future : 'dans %s',
            past : 'il y a %s',
            s : 'quelques secondes',
            m : 'une minute',
            mm : '%d minutes',
            h : 'une heure',
            hh : '%d heures',
            d : 'un jour',
            dd : '%d jours',
            M : 'un mois',
            MM : '%d mois',
            y : 'un an',
            yy : '%d ans'
        },
        dayOfMonthOrdinalParse : /\d{1,2}(er|e)/,
        ordinal : function (number) {
            return number + (number === 1 ? 'er' : 'e');
        },
        meridiemParse : /PD|MD/,
        isPM : function (input) {
            return input.charAt(0) === 'M';
        },
        // In case the meridiem units are not separated around 12, then implement
        // this function (look at locale/id.js for an example).
        // meridiemHour : function (hour, meridiem) {
        //     return /* 0-23 hour, given meridiem token and hour 1-12 */ ;
        // },
        meridiem : function (hours, minutes, isLower) {
            return hours < 12 ? 'PD' : 'MD';
        },
        week : {
            dow : 1, // Monday is the first day of the week.
            doy : 4  // Used to determine first week of the year.
        }
    });

    return (
        <>
            <article className="w-full flex bg-white p-5 rounded-lg drop-shadow-md dark:bg-gray-900">
                <div className="w-14">
                    <img src={author.profilThumbImageUrl} alt="" className="block w-12 h-12 object-cover rounded-full"/>
                </div>
                <div className="pl-4 w-full">
                    <h1 className="text-lg font-medium text-gray-900 dark:text-gray-50"><a href="#">{author.name}</a></h1>
                    <ul className="flex items-center text-gray-500">
                        {/* <li><a href="#">Meteolamer</a></li>
                        <li className="text-[8px] px-2 pt-1"><i class="fa-solid fa-circle"></i></li> */}
                        <li>{moment.unix(date).format("ddd DD MMM YYYY - HH:mm")}</li>
                    </ul>
                    <p className="pt-4 text-lg text-gray-900 dark:text-gray-50 font-light">
                        { text }
                    </p>
                    {
                        image && (
                            <div className="pt-4">
                                <img src={image} className="w-full h-auto rounded" />
                            </div>
                        )
                    }
                    <ul className="pt-6 flex text-lg text-gray-700 justify-between dark:text-gray-400">
                        <li>
                            <a href="#" className="dark:hover:text-gray-50"><i class="fa-regular fa-comment"></i> Commentaire</a>
                        </li>
                        <li>
                            <a href="#" className="dark:hover:text-gray-50"><i class="fa-regular fa-thumbs-up"></i> J'aime</a>
                        </li>
                        <li>
                            <a href="#" className="dark:hover:text-gray-50"><i class="fa-regular fa-share-from-square"></i> Partager</a>
                        </li>
                    </ul>
                </div>
            </article>
        </>
    )
}

export default Article;